***Replication file for Testing public reactions to mass protest hybrid media events: a rolling cross-sectional study of International Women's Day in Spain. Accepted in Public Opinion Quarterly****

use "..../PROTEICA2019.dta" 

set scheme s1mono


***Table A1-Summary statistics
sum knowevent2 inteventdic seekinfodic speakevdic onlinedic selwomdic treatment women education age prevpart

**Table A2-Awareness of March 8, 2019**
logit knowevent2 treatment
estimates store M1
logit knowevent2 treatment women education age prevpart
estimates store M2
gen inter=treatment*women
gen inter2=treatment*prevpart

label variable inter "treatment*gender"
label variable inter2 "treatment*pastpart"

logit knowevent2 treatment women education age prevpart inter
estimates store M3

logit knowevent2 treatment women  education age prevpart inter2
estimates store M4

estout M1 M2 M3 M4, cells(b(star fmt(3)) se)  stats(N r2) 


***-Table A3: Degree of interest in March 8, 2019

**Resumen de tablas de estimacion**
logit inteventdic treatment
estimates store M1
logit inteventdic treatment women education age prevpart
estimates store M2
logit inteventdic treatment women education age prevpart inter 
estimates store M3
logit inteventdic treatment women education age prevpart inter2 
estimates store M4
estout M1 M2 M3 M4, cells(b(star fmt(3)) se)  stats(N r2) 


***3)- Table A4-Actively seeking info about March 8, 2019

logit seekinfodic treatment
estimates store M1
logit seekinfodic treatment women education age prevpart
estimates store M2
logit seekinfodic treatment women education age prevpart inter 
estimates store M3
logit seekinfodic treatment women education age prevpart inter2 
estimates store M4

estout M1 M2 M3 M4, cells(b(star fmt(3)) se)  stats(N r2) 
		
	
***Figure 2-Treatment effect on probabilities of declaring awareness, interest, and seeking information about the mobilization of March 8th

set more off
logit knowevent2 treatment women education age prevpart
est store m1
logit inteventdic treatment women education age prevpart
est store m2
logit seekinfodic treatment women education age prevpart 
est store m3

coefplot (m1, label(Awareness)) (m2, label(Interest)) (m3, label(Information)), drop(_cons) baselevels xline(0) 
	
***Figure 3-Interaction treatment and previos participation (2018 IWD protest event) for awareness and interest
logit knowevent2 women education age prevpart##i.treatment
margins prevpart#treatment
marginsplot, recast(scatter) title("Awarness") name(i1, replace)	
logit inteventdic women education age prevpart##i.treatment
margins prevpart#treatment
marginsplot, recast(scatter) title("Interest") name(i2, replace)	

graph combine i1 i2, ycommon saving(graphs\fig3interaction.gph, replace) ysize(7) xsize(10)


						   
***Table A5- Speak about March 8, 2019
logit speakevdic treatment
estimates store M1
logit speakevdic treatment women education age prevpart
estimates store M2
logit speakevdic treatment women education age prevpart inter
estimates store M3
logit speakevdic treatment women education age prevpart inter2
estimates store M4
estout M1 M2 M3 M4, cells(b(star fmt(3)) se)  stats(N r2) 	

	
***Table A6- Interaction with others through social media
logit onlinedic treatment
estimates store M1
logit onlinedic treatment women education age prevpart
estimates store M2
logit onlinedic treatment women education age prevpart inter
estimates store M3
logit onlinedic treatment women education age prevpart inter2
estimates store M4
estout M1 M2 M3 M4, cells(b(star fmt(3)) se)  stats(N r2) 	


**Table A7-Opinion formation about gender equality
logit selwomdic treatment
estimates store M1
logit selwomdic treatment women education age prevpart
estimates store M2
logit selwomdic treatment women education age prevpart inter
estimates store M3
logit selwomdic treatment women education age prevpart inter2
estimates store M4
estout M1 M2 M3 M4, cells(b(star fmt(3)) se)  stats(N r2) 	


**Figure 4-Treatment effect on f2f conversation, online interaction about the mobilization of March 8th, and opinion formation
set more off
logit speakevdic treatment women education age prevpart 
est store m1
set more off
logit onlinedic treatment women education age prevpart 
est store m2
set more off
logit selwomdic treatment women education age prevpart 
est store m3
coefplot (m1, label(F2Ftalk)) (m2, label(Online interaction)) (m3, label(Opinion formation)), drop(_cons) baselevels xline(0) 


**Figure 5-Interaction between treatment and previos participation (2018 IWD protest event) for online interaction and between treatment and gender for opinion formation
logit onlinedic women education age prevpart##i.treatment
margins prevpart#treatment
marginsplot, recast(scatter) title("Online Interaction") name(i3, replace)

logit selwomdic  education age prevpart women##i.treatment
margins women#treatment
marginsplot, recast(scatter)title("Opinion Formation") name(i4, replace)	

graph combine i3 i4, ycommon saving(graphs\fig5interaction.gph, replace) ysize(7) xsize(10)

	

***Figure A1***

gen treat0=0
recode treat0 0=1 if TRAMO20>8
tab treat0


gen treat1=0
recode treat1 0=1 if TRAMO20>9
tab treat1

*treatment= TRAMO>10

gen treat2=0
recode treat2 0=1 if TRAMO20>11
tab treat2

gen treat3=0
recode treat3 0=1 if TRAMO20>12
tab treat3

gen treat4=0
recode treat4 0=1 if TRAMO20>13
tab treat4

tab1 treat*

**1: knowevent2
set more off
logit knowevent2 treat0 
est store m1
logit knowevent2 treat1 
est store m2
logit knowevent2 treatment 
est store m3
logit knowevent2 treat2 
est store m4
logit knowevent2 treat3 
est store m5
logit knowevent2 treat4
est store m6

set scheme s1mono 
coefplot (m1, label(day9)) (m2, label(day10)) (m3, label(day11)) (m4, label(day12)) (m5, label(day13)) (m6, label(day14)), drop(_cons) baselevels title("Awareness") name(a1, replace)

***2: inteventdic 
set more off
logit inteventdic treat0 
est store m1
logit inteventdic treat1 
est store m2
logit inteventdic treatment 
est store m3
logit inteventdic treat2 
est store m4
logit inteventdic treat3 
est store m5
logit inteventdic treat4 
est store m6
coefplot (m1, label(day9)) (m2, label(day10)) (m3, label(day11)) (m4, label(day12)) (m5, label(day13)) (m6, label(day14)), drop(_cons) baselevels  title("Interest") name(a2, replace)

***3: seekinfodic

set more off
logit seekinfodic treat0 
est store m1
logit seekinfodic treat1 
est store m2
logit seekinfodic treatment
est store m3
logit seekinfodic treat2 
est store m4
logit seekinfodic treat3 
est store m5
logit seekinfodic treat4 
est store m6
coefplot (m1, label(day9)) (m2, label(day10)) (m3, label(day11)) (m4, label(day12)) (m5, label(day13)) (m6, label(day14)), drop(_cons) baselevels  title("Infoseek") name(a3, replace)

***4:speakevdic
set more off
logit speakevdic treat0 
est store m1
logit speakevdic treat1 
est store m2
logit speakevdic treatment 
est store m3
logit speakevdic treat2 
est store m4
logit speakevdic treat3 
est store m5
logit speakevdic treat4 
est store m6
coefplot (m1, label(day9)) (m2, label(day10)) (m3, label(day11)) (m4, label(day12)) (m5, label(day13)) (m6, label(day14)), drop(_cons) baselevels  title("F2FTalk") name(a4, replace)

***5:onlinedic 
set more off
logit onlinedic treat0 
est store m1
logit onlinedic treat1 
est store m2
logit onlinedic treatment 
est store m3
logit onlinedic treat2
est store m4
logit onlinedic treat3 
est store m5
logit onlinedic treat4 
est store m6
coefplot (m1, label(day9)) (m2, label(day10)) (m3, label(day11)) (m4, label(day12)) (m5, label(day13)) (m6, label(day14)), drop(_cons) baselevels title("On line interaction") name(a5, replace)


**6: selwomdic	
set more off
logit selwomdic treat0 
est store m1
logit selwomdic treat1 
est store m2
logit selwomdic treatment 
est store m3
logit selwomdic treat2
est store m4
logit selwomdic treat3 
est store m5
logit selwomdic treat4 
est store m6
coefplot (m1, label(day9)) (m2, label(day10)) (m3, label(day11)) (m4, label(day12)) (m5, label(day13)) (m6, label(day14)), drop(_cons) baselevels title("Opinion formation") name(a6, replace)


graph combine a1 a2 a3 a4 a5 a6, ycommon saving(graphs\figA1.gph, replace) ysize(7) xsize(10)
							
